@@ -7,9 +7,10 @@ from collections import defaultdict
 
 from plumbum.lib import six, getdoc
 from .terminal import get_terminal_size
-from .switches import (SwitchError, UnknownSwitch, MissingArgument, WrongArgumentType,
-    MissingMandatorySwitch, SwitchCombinationError, PositionalArgumentsError, switch,
-    SubcommandError, Flag, CountOf)
+from .switches import (SwitchError, UnknownSwitch, MissingArgument,
+                       WrongArgumentType, MissingMandatorySwitch,
+                       SwitchCombinationError, PositionalArgumentsError,
+                       switch, SubcommandError, Flag, CountOf)
 
 from plumbum import colors, local
 from plumbum.cli.i18n import get_translation_for
@@ -20,22 +21,30 @@ T_, ngettext = _translation.gettext, _translation.ngettext
 
 class ShowHelp(SwitchError):
     pass
+
+
 class ShowHelpAll(SwitchError):
     pass
+
+
 class ShowVersion(SwitchError):
     pass
 
+
 class SwitchParseInfo(object):
     __slots__ = ["swname", "val", "index", "__weakref__"]
+
     def __init__(self, swname, val, index):
         self.swname = swname
         self.val = val
         self.index = index
 
+
 class Subcommand(object):
     def __init__(self, name, subapplication):
         self.name = name
         self.subapplication = subapplication
+
     def get(self):
         if isinstance(self.subapplication, str):
             modname, clsname = self.subapplication.rsplit(".", 1)
@@ -48,20 +57,23 @@ class Subcommand(object):
         return self.subapplication
 
     def __repr__(self):
-        return T_("Subcommand({self.name}, {self.subapplication})").format(self=self)
+        return T_("Subcommand({self.name}, {self.subapplication})").format(
+            self=self)
+
 
 _switch_groups = ['Switches', 'Meta-switches']
 _switch_groups_l10n = [T_('Switches'), T_('Meta-switches')]
+
 #===================================================================================================
 # CLI Application base class
 #===================================================================================================
 
+
 class Application(object):
-    """
-    The base class for CLI applications; your "entry point" class should derive from it,
+    """The base class for CLI applications; your "entry point" class should derive from it,
     define the relevant switch functions and attributes, and the ``main()`` function.
     The class defines two overridable "meta switches" for version (``-v``, ``--version``)
-    and help (``-h``, ``--help``).
+    help (``-h``, ``--help``), and help-all (``--help-all``).
 
     The signature of the main function matters: any positional arguments (e.g., non-switch
     arguments) given on the command line are passed to the ``main()`` function; if you wish
@@ -69,7 +81,7 @@ class Application(object):
     of the arguments will be shown in the help message.
 
     The classmethod ``run`` serves as the entry point of the class. It parses the command-line
-    arguments, invokes switch functions and enter ``main``. You should **not override** this
+    arguments, invokes switch functions and enters ``main``. You should **not override** this
     method.
 
     Usage::
@@ -89,13 +101,19 @@ class Application(object):
     There are several class-level attributes you may set:
 
     * ``PROGNAME`` - the name of the program; if ``None`` (the default), it is set to the
-      name of the executable (``argv[0]``), can be in color. If only a color, will be applied to the name.
+      name of the executable (``argv[0]``); can be in color. If only a color, will be applied to the name.
 
     * ``VERSION`` - the program's version (defaults to ``1.0``, can be in color)
 
     * ``DESCRIPTION`` - a short description of your program (shown in help). If not set,
       the class' ``__doc__`` will be used. Can be in color.
 
+    * ``DESCRIPTION_MORE`` - a detailed description of your program (shown in help). The text will be printed
+      by paragraphs (specified by empty lines between them). The indentation of each paragraph will be the
+      indentation of its first line. List items are identified by their first non-whitespace character being
+      one of '-', '*', and '/'; so that they are not combined with preceding paragraphs. Bullet '/' is
+      "invisible", meaning that the bullet itself will not be printed to the output.
+
     * ``USAGE`` - the usage line (shown in help)
 
     * ``COLOR_USAGE`` - The color of the usage line
@@ -104,23 +122,30 @@ class Application(object):
       and Subcommands
 
     * ``SUBCOMMAND_HELPMSG`` - Controls the printing of extra "see subcommand -h" help message.
-      Default is a message, set to false to remove.
+      Default is a message, set to False to remove.
+
+    * ``ALLOW_ABBREV`` - Controls whether partial switch names are supported, for example '--ver' will match
+      '--verbose'. Default is False for backward consistency with previous plumbum releases. Note that ambiguous
+      abbreviations will not match, for example if --foothis and --foothat are defined, then --foo will not match.
 
     A note on sub-commands: when an application is the root, its ``parent`` attribute is set to
-    ``None``. When it is used as a nested-command, ``parent`` will point to be its direct ancestor.
+    ``None``. When it is used as a nested-command, ``parent`` will point to its direct ancestor.
     Likewise, when an application is invoked with a sub-command, its ``nested_command`` attribute
     will hold the chosen sub-application and its command-line arguments (a tuple); otherwise, it
     will be set to ``None``
+
     """
 
     PROGNAME = None
     DESCRIPTION = None
+    DESCRIPTION_MORE = None
     VERSION = None
     USAGE = None
     COLOR_USAGE = None
     COLOR_GROUPS = None
     CALL_MAIN_IF_NESTED_COMMAND = True
     SUBCOMMAND_HELPMSG = T_("see '{parent} {sub} --help' for more info")
+    ALLOW_ABBREV = False
 
     parent = None
     nested_command = None
@@ -128,10 +153,9 @@ class Application(object):
 
     def __new__(cls, executable=None):
         """Allows running the class directly as a shortcut for main.
-        This is neccisary for some setup scripts that want a single function,
+        This is necessary for some setup scripts that want a single function,
         instead of an expression with a dot in it."""
 
-
         if executable is None:
             return cls.run()
             # This return value was not a class instance, so __init__ is never called
@@ -146,14 +170,16 @@ class Application(object):
         elif isinstance(self.PROGNAME, colors._style):
             self.PROGNAME = self.PROGNAME | os.path.basename(executable)
         elif colors.filter(self.PROGNAME) == '':
-            self.PROGNAME = colors.extract(self.PROGNAME) | os.path.basename(executable)
+            self.PROGNAME = colors.extract(
+                self.PROGNAME) | os.path.basename(executable)
         if self.DESCRIPTION is None:
             self.DESCRIPTION = getdoc(self)
 
         # Allow None for the colors
         self.COLOR_GROUPS = defaultdict(
-            lambda:colors.do_nothing,
-            dict() if type(self).COLOR_GROUPS is None else type(self).COLOR_GROUPS)
+            lambda: colors.do_nothing,
+            dict()
+            if type(self).COLOR_GROUPS is None else type(self).COLOR_GROUPS)
         if type(self).COLOR_USAGE is None:
             self.COLOR_USAGE = colors.do_nothing
 
@@ -168,8 +194,9 @@ class Application(object):
                 if isinstance(obj, Subcommand):
                     name = colors.filter(obj.name)
                     if name.startswith("-"):
-                        raise SubcommandError(T_("Subcommand names cannot start with '-'"))
-                    # it's okay for child classes to override subcommands set by their parents
+                        raise SubcommandError(
+                            T_("Sub-command names cannot start with '-'"))
+                    # it's okay for child classes to override sub-commands set by their parents
                     self._subcommands[name] = obj
                     continue
 
@@ -181,13 +208,13 @@ class Application(object):
                         continue
                     if name in self._switches_by_name and not self._switches_by_name[name].overridable:
                         raise SwitchError(
-                            T_("Switch {name} already defined and is not overridable").format(name=name))
+                            T_("Switch {name} already defined and is not overridable"
+                               ).format(name=name))
                     self._switches_by_name[name] = swinfo
                     self._switches_by_func[swinfo.func] = swinfo
                     if swinfo.envname:
                         self._switches_by_envar[swinfo.envname] = swinfo
 
-
     @property
     def root_app(self):
         return self.parent.root_app if self.parent else self
@@ -203,10 +230,11 @@ class Application(object):
             MyApp.unbind_switches("--version")
 
         """
-        cls._unbound_switches += tuple(name.lstrip("-") for name in switch_names if name)
+        cls._unbound_switches += tuple(
+            name.lstrip("-") for name in switch_names if name)
 
     @classmethod
-    def subcommand(cls, name, subapp = None):
+    def subcommand(cls, name, subapp=None):
         """Registers the given sub-application as a sub-command of this one. This method can be
         used both as a decorator and as a normal ``classmethod``::
 
@@ -221,19 +249,28 @@ class Application(object):
         .. versionadded:: 1.1
 
         .. versionadded:: 1.3
-            The subcommand can also be a string, in which case it is treated as a
-            fully-qualified class name and is imported on demand. For examples,
+            The sub-command can also be a string, in which case it is treated as a
+            fully-qualified class name and is imported on demand. For example,
 
             MyApp.subcommand("foo", "fully.qualified.package.FooApp")
 
         """
+
         def wrapper(subapp):
             attrname = "_subcommand_{0}".format(
                 subapp if isinstance(subapp, str) else subapp.__name__)
             setattr(cls, attrname, Subcommand(name, subapp))
             return subapp
+
         return wrapper(subapp) if subapp else wrapper
 
+    def _get_partial_matches(self, partialname):
+        matches = []
+        for switch in self._switches_by_name:
+            if switch.startswith(partialname):
+                matches += [switch, ]
+        return matches
+
     def _parse_args(self, argv):
         tailargs = []
         swfuncs = {}
@@ -250,7 +287,9 @@ class Application(object):
 
             if a in self._subcommands:
                 subcmd = self._subcommands[a].get()
-                self.nested_command = (subcmd, [self.PROGNAME + " " + self._subcommands[a].name] + argv)
+                self.nested_command = (
+                    subcmd,
+                    [self.PROGNAME + " " + self._subcommands[a].name] + argv)
                 break
 
             elif a.startswith("--") and len(a) >= 3:
@@ -262,20 +301,34 @@ class Application(object):
                     argv.insert(0, a[eqsign:])
                 else:
                     name = a[2:]
+
+                if self.ALLOW_ABBREV:
+                    partials = self._get_partial_matches(name)
+                    if len(partials) == 1:
+                        name = partials[0]
+                    elif len(partials) > 1:
+                        raise UnknownSwitch(
+                            T_("Ambiguous partial switch {0}").format("--" + name))
+
                 swname = "--" + name
                 if name not in self._switches_by_name:
-                    raise UnknownSwitch(T_("Unknown switch {0}").format(swname))
+                    raise UnknownSwitch(
+                        T_("Unknown switch {0}").format(swname))
                 swinfo = self._switches_by_name[name]
                 if swinfo.argtype:
                     if not argv:
-                        raise MissingArgument(T_("Switch {0} requires an argument").format(swname))
+                        raise MissingArgument(
+                            T_("Switch {0} requires an argument").format(
+                                swname))
                     a = argv.pop(0)
                     if a and a[0] == "=":
                         if len(a) >= 2:
                             val = a[1:]
                         else:
                             if not argv:
-                                raise MissingArgument(T_("Switch {0} requires an argument").format(swname))
+                                raise MissingArgument(
+                                    T_("Switch {0} requires an argument")
+                                    .format(swname))
                             val = argv.pop(0)
                     else:
                         val = a
@@ -285,14 +338,17 @@ class Application(object):
                 name = a[1]
                 swname = "-" + name
                 if name not in self._switches_by_name:
-                    raise UnknownSwitch(T_("Unknown switch {0}").format(swname))
+                    raise UnknownSwitch(
+                        T_("Unknown switch {0}").format(swname))
                 swinfo = self._switches_by_name[name]
                 if swinfo.argtype:
                     if len(a) >= 3:
                         val = a[2:]
                     else:
                         if not argv:
-                            raise MissingArgument(T_("Switch {0} requires an argument").format(swname))
+                            raise MissingArgument(
+                                T_("Switch {0} requires an argument").format(
+                                    swname))
                         val = argv.pop(0)
                 elif len(a) >= 3:
                     argv.insert(0, "-" + a[2:])
@@ -311,18 +367,21 @@ class Application(object):
                     swfuncs[swinfo.func].val[0].append(val)
                 else:
                     if swfuncs[swinfo.func].swname == swname:
-                        raise SwitchError(T_("Switch {0} already given").format(swname))
+                        raise SwitchError(
+                            T_("Switch {0} already given").format(swname))
                     else:
                         raise SwitchError(
-                            T_("Switch {0} already given ({1} is equivalent)").format(
-                                swfuncs[swinfo.func].swname, swname))
+                            T_("Switch {0} already given ({1} is equivalent)")
+                            .format(swfuncs[swinfo.func].swname, swname))
             else:
                 if swinfo.list:
-                    swfuncs[swinfo.func] = SwitchParseInfo(swname, ([val],), index)
+                    swfuncs[swinfo.func] = SwitchParseInfo(
+                        swname, ([val], ), index)
                 elif val is NotImplemented:
                     swfuncs[swinfo.func] = SwitchParseInfo(swname, (), index)
                 else:
-                    swfuncs[swinfo.func] = SwitchParseInfo(swname, (val,), index)
+                    swfuncs[swinfo.func] = SwitchParseInfo(
+                        swname, (val, ), index)
 
         # Extracting arguments from environment variables
         envindex = 0
@@ -340,11 +399,13 @@ class Application(object):
             if swinfo.list:
                 # multiple values over environment variables are not supported,
                 # this will require some sort of escaping and separator convention
-                swfuncs[swinfo.func] = SwitchParseInfo(envname, ([val],), envindex)
+                swfuncs[swinfo.func] = SwitchParseInfo(envname, ([val], ),
+                                                       envindex)
             elif val is NotImplemented:
                 swfuncs[swinfo.func] = SwitchParseInfo(envname, (), envindex)
             else:
-                swfuncs[swinfo.func] = SwitchParseInfo(envname, (val,), envindex)
+                swfuncs[swinfo.func] = SwitchParseInfo(envname, (val, ),
+                                                       envindex)
 
         return swfuncs, tailargs
 
@@ -360,8 +421,9 @@ class Application(object):
                 return argtype(val)
             except (TypeError, ValueError):
                 ex = sys.exc_info()[1]  # compat
-                raise WrongArgumentType(T_("Argument of {name} expected to be {argtype}, not {val!r}:\n    {ex!r}").format(
-                    name=name, argtype=argtype, val=val, ex=ex))
+                raise WrongArgumentType(
+                    T_("Argument of {name} expected to be {argtype}, not {val!r}:\n    {ex!r}"
+                       ).format(name=name, argtype=argtype, val=val, ex=ex))
         else:
             return NotImplemented
 
@@ -377,10 +439,14 @@ class Application(object):
         exclusions = {}
         for swinfo in self._switches_by_func.values():
             if swinfo.mandatory and not swinfo.func in swfuncs:
-                raise MissingMandatorySwitch(T_("Switch {0} is mandatory").format(
-                    "/".join(("-" if len(n) == 1 else "--") + n for n in swinfo.names)))
-            requirements[swinfo.func] = set(self._switches_by_name[req] for req in swinfo.requires)
-            exclusions[swinfo.func] = set(self._switches_by_name[exc] for exc in swinfo.excludes)
+                raise MissingMandatorySwitch(
+                    T_("Switch {0} is mandatory").format("/".join(
+                        ("-" if len(n) == 1 else "--") + n
+                        for n in swinfo.names)))
+            requirements[swinfo.func] = set(
+                self._switches_by_name[req] for req in swinfo.requires)
+            exclusions[swinfo.func] = set(
+                self._switches_by_name[exc] for exc in swinfo.excludes)
 
         # TODO: compute topological order
 
@@ -396,7 +462,8 @@ class Application(object):
             if invalid:
                 raise SwitchCombinationError(
                     T_("Given {0}, the following are invalid {1}").format(
-                        swfuncs[func].swname, [swfuncs[f].swname for f in invalid]))
+                        swfuncs[func].swname,
+                        [swfuncs[f].swname for f in invalid]))
 
         m = six.getfullargspec(self.main)
         max_args = six.MAXSIZE if m.varargs else len(m.args) - 1
@@ -409,22 +476,22 @@ class Application(object):
                     min_args).format(min_args, tailargs))
         elif len(tailargs) > max_args:
             raise PositionalArgumentsError(
-                ngettext(
-                    "Expected at most {0} positional argument, got {1}",
-                    "Expected at most {0} positional arguments, got {1}",
-                    max_args).format(max_args, tailargs))
+                ngettext("Expected at most {0} positional argument, got {1}",
+                         "Expected at most {0} positional arguments, got {1}",
+                         max_args).format(max_args, tailargs))
 
         # Positional arguement validataion
         if hasattr(self.main, 'positional'):
-            tailargs = self._positional_validate(tailargs, self.main.positional, self.main.positional_varargs, m.args[1:], m.varargs)
+            tailargs = self._positional_validate(
+                tailargs, self.main.positional, self.main.positional_varargs,
+                m.args[1:], m.varargs)
 
         elif hasattr(m, 'annotations'):
             args_names = list(m.args[1:])
-            positional = [None]*len(args_names)
+            positional = [None] * len(args_names)
             varargs = None
 
-
-             # All args are positional, so convert kargs to positional
+            # All args are positional, so convert kargs to positional
             for item in m.annotations:
                 if item == m.varargs:
                     varargs = m.annotations[item]
@@ -434,30 +501,35 @@ class Application(object):
             tailargs = self._positional_validate(tailargs, positional, varargs,
                                                  m.args[1:], m.varargs)
 
-        ordered = [(f, a) for _, f, a in
-            sorted([(sf.index, f, sf.val) for f, sf in swfuncs.items()])]
+        ordered = [(f, a)
+                   for _, f, a in sorted([(sf.index, f, sf.val)
+                                          for f, sf in swfuncs.items()])]
         return ordered, tailargs
 
-    def _positional_validate(self, args, validator_list, varargs, argnames, varargname):
+    def _positional_validate(self, args, validator_list, varargs, argnames,
+                             varargname):
         """Makes sure args follows the validation given input"""
         out_args = list(args)
 
-        for i in range(min(len(args),len(validator_list))):
+        for i in range(min(len(args), len(validator_list))):
 
             if validator_list[i] is not None:
-                out_args[i] = self._handle_argument(args[i], validator_list[i], argnames[i])
+                out_args[i] = self._handle_argument(args[i], validator_list[i],
+                                                    argnames[i])
 
         if len(args) > len(validator_list):
             if varargs is not None:
                 out_args[len(validator_list):] = [
-                    self._handle_argument(a, varargs, varargname) for a in args[len(validator_list):]]
+                    self._handle_argument(a, varargs, varargname)
+                    for a in args[len(validator_list):]
+                ]
             else:
                 out_args[len(validator_list):] = args[len(validator_list):]
 
         return out_args
 
     @classmethod
-    def run(cls, argv = None, exit = True):  # @ReservedAssignment
+    def run(cls, argv=None, exit=True):  # @ReservedAssignment
         """
         Runs the application, taking the arguments from ``sys.argv`` by default if
         nothing is passed. If ``exit`` is
@@ -468,7 +540,7 @@ class Application(object):
 
         .. note::
            Setting ``exit`` to ``False`` is intendend for testing/debugging purposes only -- do
-           not override it other situations.
+           not override it in other situations.
         """
         if argv is None:
             argv = sys.argv
@@ -502,7 +574,7 @@ class Application(object):
             if not retcode and inst.nested_command:
                 subapp, argv = inst.nested_command
                 subapp.parent = inst
-                inst, retcode = subapp.run(argv, exit = False)
+                inst, retcode = subapp.run(argv, exit=False)
 
             if cleanup:
                 cleanup()
@@ -540,7 +612,7 @@ class Application(object):
         if not retcode and inst.nested_command:
             subapp, argv = inst.nested_command
             subapp.parent = inst
-            inst, retcode = subapp.run(argv, exit = False)
+            inst, retcode = subapp.run(argv, exit=False)
 
         if cleanup:
             cleanup()
@@ -554,16 +626,19 @@ class Application(object):
             switch = getattr(type(self), swname)
             swinfo = self._switches_by_func[switch._switch_info.func]
             if isinstance(switch, CountOf):
-                p = (range(val),)
+                p = (range(val), )
             elif swinfo.list and not hasattr(val, "__iter__"):
-                raise SwitchError(T_("Switch {0} must be a sequence (iterable)").format(swname))
+                raise SwitchError(
+                    T_("Switch {0} must be a sequence (iterable)").format(
+                        swname))
             elif not swinfo.argtype:
                 # a flag
                 if val not in (True, False, None, Flag):
-                    raise SwitchError(T_("Switch {0} is a boolean flag").format(swname))
+                    raise SwitchError(
+                        T_("Switch {0} is a boolean flag").format(swname))
                 p = ()
             else:
-                p = (val,)
+                p = (val, )
             swfuncs[swinfo.func] = SwitchParseInfo(swname, p, index)
         return swfuncs
 
@@ -585,16 +660,18 @@ class Application(object):
             return 1
 
     def cleanup(self, retcode):
-        """Called after ``main()`` and all subapplications have executed, to perform any necessary cleanup.
+        """Called after ``main()`` and all sub-applications have executed, to perform any necessary cleanup.
 
         :param retcode: the return code of ``main()``
         """
 
     @switch(
-        ["--help-all"], overridable = True, group = "Meta-switches",
-        help=T_("""Print help messages of all subcommands and quit"""))
+        ["--help-all"],
+        overridable=True,
+        group="Meta-switches",
+        help=T_("""Prints help messages of all sub-commands and quits"""))
     def helpall(self):
-        """Print help messages of all subcommands and quit"""
+        """Prints help messages of all sub-commands and quits"""
         self.help()
         print("")
 
@@ -608,7 +685,9 @@ class Application(object):
                 subapp.helpall()
 
     @switch(
-        ["-h", "--help"], overridable = True, group = "Meta-switches",
+        ["-h", "--help"],
+        overridable=True,
+        group="Meta-switches",
         help=T_("""Prints this help message and quits"""))
     def help(self):  # @ReservedAssignment
         """Prints this help message and quits"""
@@ -618,23 +697,136 @@ class Application(object):
         if self.DESCRIPTION:
             print(self.DESCRIPTION.strip() + '\n')
 
+        def split_indentation(s):
+            """Identifies the initial indentation (all spaces) of the string and returns the indentation as well
+            as the remainder of the line.
+            """
+            i = 0
+            while i < len(s) and s[i] == ' ':
+                i += 1
+            return s[:i], s[i:]
+
+        def paragraphs(text):
+            """Yields each paragraph of text along with its initial and subsequent indentations to be used by
+            textwrap.TextWrapper.
+
+            Identifies list items from their first non-space character being one of bullets '-', '*', and '/'.
+            However, bullet '/' is invisible and is removed from the list item.
+
+            :param text: The text to separate into paragraphs
+            """
+
+            paragraph = None
+            initial_indent = ""
+            subsequent_indent = ""
+
+            def current():
+                """Yields the current result if present.
+                """
+                if paragraph:
+                    yield paragraph, initial_indent, subsequent_indent
+
+            for part in text.lstrip("\n").split("\n"):
+                indent, line = split_indentation(part)
+
+                if len(line) == 0:
+                    # Starting a new paragraph
+                    for item in current():
+                        yield item
+                    yield "", "", ""
+
+                    paragraph = None
+                    initial_indent = ""
+                    subsequent_indent = ""
+                else:
+                    # Adding to current paragraph
+                    def is_list_item(line):
+                        """Returns true if the first element of 'line' is a bullet character.
+                        """
+                        bullets = ['-', '*', '/']
+                        return line[0] in bullets
+
+                    def has_invisible_bullet(line):
+                        """Returns true if the first element of 'line' is the invisible bullet ('/').
+                        """
+                        return line[0] == '/'
+
+                    if is_list_item(line):
+                        # Done with current paragraph
+                        for item in current():
+                            yield item
+
+                        if has_invisible_bullet(line):
+                            line = line[1:]
+
+                        paragraph = line
+                        initial_indent = indent
+
+                        # Calculate extra indentation for subsequent lines of this list item
+                        i = 1
+                        while i < len(line) and line[i] == ' ':
+                            i += 1
+                        subsequent_indent = indent + " " * i
+                    else:
+                        if not paragraph:
+                            # Start a new paragraph
+                            paragraph = line
+                            initial_indent = indent
+                            subsequent_indent = indent
+                        else:
+                            # Add to current paragraph
+                            paragraph = paragraph + ' ' + line
+
+            for item in current():
+                yield item
+
+        def wrapped_paragraphs(text, width):
+            """Yields each line of each paragraph of text after wrapping them on 'width' number of columns.
+
+            :param text: The text to yield wrapped lines of
+            :param width: The width of the wrapped output
+            """
+            if not text:
+                return
+
+            width = max(width, 1)
+
+            for paragraph, initial_indent, subsequent_indent in paragraphs(
+                    text):
+                wrapper = TextWrapper(
+                    width,
+                    initial_indent=initial_indent,
+                    subsequent_indent=subsequent_indent)
+                w = wrapper.wrap(paragraph)
+                for line in w:
+                    yield line
+                if len(w) == 0:
+                    yield ""
+
+        cols, _ = get_terminal_size()
+        for line in wrapped_paragraphs(self.DESCRIPTION_MORE, cols):
+            print(line)
+
         m = six.getfullargspec(self.main)
         tailargs = m.args[1:]  # skip self
         if m.defaults:
             for i, d in enumerate(reversed(m.defaults)):
                 tailargs[-i - 1] = "[{0}={1}]".format(tailargs[-i - 1], d)
         if m.varargs:
-            tailargs.append("{0}...".format(m.varargs,))
+            tailargs.append("{0}...".format(m.varargs, ))
         tailargs = " ".join(tailargs)
 
         with self.COLOR_USAGE:
             print(T_("Usage:"))
             if not self.USAGE:
                 if self._subcommands:
-                    self.USAGE = T_("    {progname} [SWITCHES] [SUBCOMMAND [SWITCHES]] {tailargs}\n")
+                    self.USAGE = T_(
+                        "    {progname} [SWITCHES] [SUBCOMMAND [SWITCHES]] {tailargs}\n"
+                    )
                 else:
                     self.USAGE = T_("    {progname} [SWITCHES] {tailargs}\n")
-            print(self.USAGE.format(progname=colors.filter(self.PROGNAME), tailargs=tailargs))
+            print(self.USAGE.format(
+                progname=colors.filter(self.PROGNAME), tailargs=tailargs))
 
         by_groups = {}
         for si in self._switches_by_func.values():
@@ -643,20 +835,24 @@ class Application(object):
             by_groups[si.group].append(si)
 
         def switchs(by_groups, show_groups):
-            for grp, swinfos in sorted(by_groups.items(), key = lambda item: item[0]):
+            for grp, swinfos in sorted(
+                    by_groups.items(), key=lambda item: item[0]):
                 if show_groups:
                     lgrp = T_(grp) if grp in _switch_groups else grp
                     print(self.COLOR_GROUPS[grp] | lgrp + ':')
 
-                for si in sorted(swinfos, key = lambda si: si.names):
-                    swnames = ", ".join(("-" if len(n) == 1 else "--") + n for n in si.names
-                        if n in self._switches_by_name and self._switches_by_name[n] == si)
+                for si in sorted(swinfos, key=lambda si: si.names):
+                    swnames = ", ".join(("-" if len(n) == 1 else "--") + n
+                                        for n in si.names
+                                        if n in self._switches_by_name
+                                        and self._switches_by_name[n] == si)
                     if si.argtype:
                         if hasattr(si.argtype, '__name__'):
                             typename = si.argtype.__name__
                         else:
                             typename = str(si.argtype)
-                        argtype = " {0}:{1}".format(si.argname.upper(), typename)
+                        argtype = " {0}:{1}".format(si.argname.upper(),
+                                                    typename)
                     else:
                         argtype = ""
                     prefix = swnames + argtype
@@ -665,10 +861,10 @@ class Application(object):
                 if show_groups:
                     print("")
 
-        sw_width = max(len(prefix) for si, prefix, color in switchs(by_groups, False)) + 4
-        cols, _ = get_terminal_size()
+        sw_width = max(
+            len(prefix) for si, prefix, color in switchs(by_groups, False)) + 4
         description_indent = "    {0}{1}{2}"
-        wrapper = TextWrapper(width = max(cols - min(sw_width, 60), 50) - 6)
+        wrapper = TextWrapper(width=max(cols - min(sw_width, 60), 50) - 6)
         indentation = "\n" + " " * (cols - wrapper.width)
 
         for switch_info, prefix, color in switchs(by_groups, True):
@@ -678,52 +874,55 @@ class Application(object):
             if switch_info.mandatory:
                 help += T_("; required")
             if switch_info.requires:
-                help += T_("; requires {0}").format(
-                    ", ".join(
-                        (("-" if len(switch) == 1 else "--") + switch)
-                        for switch in switch_info.requires))
+                help += T_("; requires {0}").format(", ".join(
+                    (("-" if len(switch) == 1 else "--") + switch)
+                    for switch in switch_info.requires))
             if switch_info.excludes:
-                help += T_("; excludes {0}").format(
-                    ", ".join(
-                        (("-" if len(switch) == 1 else "--") + switch)
-                        for switch in switch_info.excludes))
+                help += T_("; excludes {0}").format(", ".join(
+                    (("-" if len(switch) == 1 else "--") + switch)
+                    for switch in switch_info.excludes))
 
-            msg = indentation.join(wrapper.wrap(" ".join(l.strip() for l in help.splitlines())))
+            msg = indentation.join(
+                wrapper.wrap(" ".join(l.strip() for l in help.splitlines())))
 
             if len(prefix) + wrapper.width >= cols:
                 padding = indentation
             else:
                 padding = " " * max(cols - wrapper.width - len(prefix) - 4, 1)
-            print(description_indent.format(color | prefix, padding, color | msg))
+            print(description_indent.format(color | prefix, padding,
+                                            color | msg))
 
         if self._subcommands:
             gc = self.COLOR_GROUPS["Subcommands"]
-            print(gc | T_("Subcommands:"))
+            print(gc | T_("Sub-commands:"))
             for name, subcls in sorted(self._subcommands.items()):
                 with gc:
                     subapp = subcls.get()
-                    doc = subapp.DESCRIPTION if subapp.DESCRIPTION else getdoc(subapp)
+                    doc = subapp.DESCRIPTION if subapp.DESCRIPTION else getdoc(
+                        subapp)
                     if self.SUBCOMMAND_HELPMSG:
                         help = doc + "; " if doc else ""  # @ReservedAssignment
-                        help += self.SUBCOMMAND_HELPMSG.format(parent=self.PROGNAME, sub=name)
+                        help += self.SUBCOMMAND_HELPMSG.format(
+                            parent=self.PROGNAME, sub=name)
                     else:
-                        help = doc if doc else "" # @ReservedAssignment
+                        help = doc if doc else ""  # @ReservedAssignment
 
-                    msg = indentation.join(wrapper.wrap(" ".join(l.strip() for l in help.splitlines())))
+                    msg = indentation.join(
+                        wrapper.wrap(" ".join(
+                            l.strip() for l in help.splitlines())))
 
                     if len(name) + wrapper.width >= cols:
                         padding = indentation
                     else:
-                        padding = " " * max(cols - wrapper.width - len(name) - 4, 1)
+                        padding = " " * max(
+                            cols - wrapper.width - len(name) - 4, 1)
                     if colors.contains_colors(subcls.name):
                         bodycolor = colors.extract(subcls.name)
                     else:
                         bodycolor = gc
 
                     print(description_indent.format(
-                        subcls.name, padding,
-                        bodycolor | colors.filter(msg)))
-
+                        subcls.name, padding, bodycolor | colors.filter(msg)))
 
     def _get_prog_version(self):
         ver = None
@@ -736,7 +935,9 @@ class Application(object):
         return ver
 
     @switch(
-        ["-v", "--version"], overridable = True, group = "Meta-switches",
+        ["-v", "--version"],
+        overridable=True,
+        group="Meta-switches",
         help=T_("""Prints the program's version and quits"""))
     def version(self):
         """Prints the program's version and quits"""
