@@ -1,14 +1,18 @@
 import logging
 import errno
+import os
 import stat
 import socket
+from plumbum.commands.base import shquote
 from plumbum.machines.base import PopenAddons
 from plumbum.machines.remote import BaseRemoteMachine
 from plumbum.machines.session import ShellSession
 from plumbum.lib import _setdoc, six
 from plumbum.path.local import LocalPath
 from plumbum.path.remote import RemotePath, StatRes
-from plumbum.commands.processes import iter_lines
+from plumbum.commands.processes import iter_lines, ProcessLineTimedOut
+
+
 try:
     # Sigh... we need to gracefully-import paramiko for Sphinx builds, etc
     import paramiko
@@ -176,6 +180,10 @@ class ParamikoMachine(BaseRemoteMachine):
     :param bool gss_deleg_creds: Delegate GSS-API client credentials or not
 
     :param str gss_host: The targets name in the kerberos database. default: hostname
+
+    :param bool get_pty: Execute remote commands with allocated pseudo-tty. default: False
+
+    :param bool load_system_ssh_config: read system SSH config for ProxyCommand configuration. default: False
     """
 
     class RemoteCommand(BaseRemoteMachine.RemoteCommand):
@@ -212,7 +220,9 @@ class ParamikoMachine(BaseRemoteMachine):
                  gss_auth=False,
                  gss_kex=None,
                  gss_deleg_creds=None,
-                 gss_host=None):
+                 gss_host=None,
+                 get_pty=False,
+                 load_system_ssh_config=False):
         self.host = host
         kwargs = {}
         if user:
@@ -242,9 +252,19 @@ class ParamikoMachine(BaseRemoteMachine):
             if not gss_host:
                 gss_host = host
             kwargs['gss_host'] = gss_host
+        if load_system_ssh_config:
+            ssh_config = paramiko.SSHConfig()
+            with open(os.path.expanduser('~/.ssh/config')) as f:
+                ssh_config.parse(f)
+            try:
+                hostConfig = ssh_config.lookup(host)
+                kwargs['sock'] = paramiko.ProxyCommand(hostConfig['proxycommand'])
+            except KeyError:
+                pass
         self._client.connect(host, **kwargs)
         self._keep_alive = keep_alive
         self._sftp = None
+        self._get_pty = get_pty
         BaseRemoteMachine.__init__(self, encoding, connect_timeout)
 
     def __str__(self):
@@ -300,11 +320,11 @@ class ParamikoMachine(BaseRemoteMachine):
         argv.extend(["cd", str(cwd or self.cwd), "&&"])
         if envdelta:
             argv.append("env")
-            argv.extend("%s=%s" % (k, v) for k, v in envdelta.items())
+            argv.extend("%s=%s" % (k, shquote(v)) for k, v in envdelta.items())
         argv.extend(args.formulate())
         cmdline = " ".join(argv)
         logger.debug(cmdline)
-        si, so, se = streams = self._client.exec_command(cmdline, 1)
+        si, so, se = self._client.exec_command(cmdline, 1, get_pty=self._get_pty)
         return ParamikoPopen(
             argv,
             si,
@@ -443,7 +463,7 @@ class SocketCompatibleChannel(object):
 ###################################################################################################
 # Custom iter_lines for paramiko.Channel
 ###################################################################################################
-def _iter_lines(proc, decode, linesize):
+def _iter_lines(proc, decode, linesize, line_timeout=None):
 
     try:
         from selectors import DefaultSelector, EVENT_READ
@@ -453,7 +473,9 @@ def _iter_lines(proc, decode, linesize):
 
         def selector():
             while True:
-                rlist, _, _ = select([proc.stdout.channel], [], [])
+                rlist, _, _ = select([proc.stdout.channel], [], [], line_timeout)
+                if not rlist and line_timeout:
+                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
                 for _ in rlist:
                     yield
     else:
@@ -462,7 +484,10 @@ def _iter_lines(proc, decode, linesize):
             sel = DefaultSelector()
             sel.register(proc.stdout.channel, EVENT_READ)
             while True:
-                for key, mask in sel.select():
+                ready = sel.select(line_timeout)
+                if not ready and line_timeout:
+                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
+                for key, mask in ready:
                     yield
 
     for _ in selector():
